"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseService = void 0;
const cm_libs_context_aware_logger_1 = require("cm-libs-context-aware-logger");
const model_1 = require("../model");
const secure_log_1 = require("../misc/secure-log");
const cm_libs_utils_1 = require("cm-libs-utils");
const config_base_1 = require("../config-base");
class BaseService {
    BASE_SERVICE_LOG = config_base_1.ConfigBase.get('BASE_SERVICE_LOG', (0, cm_libs_utils_1.allowNullOrEmpty)(cm_libs_utils_1.checkBoolean, false));
    entityName;
    model;
    schemaBrowse;
    schemaRead;
    schemaEdit;
    schemaAdd;
    schemaDelete;
    schemaActivate;
    schemaDeactivate;
    constructor({ entityName, model, schemaBrowse, schemaRead, schemaEdit, schemaAdd, schemaDelete, schemaActivate, schemaDeactivate }) {
        this.entityName = entityName;
        this.model = model;
        this.schemaBrowse = schemaBrowse;
        this.schemaRead = schemaRead;
        this.schemaEdit = schemaEdit;
        this.schemaAdd = schemaAdd;
        this.schemaDelete = schemaDelete;
        this.schemaActivate = schemaActivate;
        this.schemaDeactivate = schemaDeactivate;
    }
    async browse(params, accessInfo) {
        const dbRetData = await this.model.instance.run(accessInfo, () => this.model.instance.browse(params));
        if (this.BASE_SERVICE_LOG)
            secure_log_1.SecureLog.log(cm_libs_context_aware_logger_1.Level.DEBUG, dbRetData, 'dbRetData');
        return dbRetData;
    }
    //#endregion
    //#region Read
    async read(params, accessInfo) {
        const dbRetData = await this.model.instance.run(accessInfo, () => this.model.instance.model.findUnique(params));
        if (this.BASE_SERVICE_LOG)
            secure_log_1.SecureLog.log(cm_libs_context_aware_logger_1.Level.DEBUG, dbRetData, 'dbRetData');
        return dbRetData;
    }
    //#endregion
    //#region Edit
    async edit(params, accessInfo) {
        const dbRetData = await this.model.instance.run(accessInfo, () => this.model.instance.model.update(params));
        if (this.BASE_SERVICE_LOG)
            secure_log_1.SecureLog.log(cm_libs_context_aware_logger_1.Level.DEBUG, dbRetData, 'dbRetData');
        return dbRetData;
    }
    //#endregion
    //#region Add
    async add(params, accessInfo) {
        const dbRetData = await this.model.instance.run(accessInfo, () => this.model.instance.model.create(params));
        if (this.BASE_SERVICE_LOG)
            secure_log_1.SecureLog.log(cm_libs_context_aware_logger_1.Level.DEBUG, dbRetData, 'dbRetData');
        return dbRetData;
    }
    //#endregion
    // #region Delete
    async delete(params, accessInfo) {
        const dbRetData = await this.model.instance.run(accessInfo, () => this.model.instance.model.delete(params));
        if (this.BASE_SERVICE_LOG)
            secure_log_1.SecureLog.log(cm_libs_context_aware_logger_1.Level.DEBUG, dbRetData, 'dbRetData');
        return dbRetData;
    }
    async activate(params, accessInfo) {
        const dbRetData = await this.model.instance.run(accessInfo, () => this.model.instance.model.update({ ...params, data: { status: model_1.RecordStatus.ACTIVE } }));
        if (this.BASE_SERVICE_LOG)
            secure_log_1.SecureLog.log(cm_libs_context_aware_logger_1.Level.DEBUG, dbRetData, 'dbRetData');
        return dbRetData;
    }
    async deactivate(params, accessInfo) {
        const dbRetData = await this.model.instance.run(accessInfo, () => this.model.instance.model.update({ ...params, data: { status: model_1.RecordStatus.INACTIVE } }));
        secure_log_1.SecureLog.log(cm_libs_context_aware_logger_1.Level.DEBUG, dbRetData, 'dbRetData');
        return dbRetData;
    }
}
exports.BaseService = BaseService;
//# sourceMappingURL=base.service.js.map