"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateOrThrowError = exports._rolesMetadata = exports._roleMetadata = exports._roleAttributes = exports._roleModel = exports._roleModelCreateMany = exports._roleModelCreate = exports._roleModelDeleteMany = exports._roleModelDelete = exports._roleModelUpdateMany = exports._roleModelUpdate = exports._roleModelFindMany = exports._roleModelFindUnique = exports._roleModelWhere = exports._roleModelWhereUnique = exports._roleModelSelect = exports._rules = exports._rule = exports._ruleInverted = exports._ruleConditions = exports._ruleFields = exports._ruleSubject = exports._ruleAction = exports._appDomain = exports._localeCode = exports._tokenKind = exports._userLogin = exports._modelInclude = exports._object = exports._boolean = exports._string = exports._idString = exports._id = exports.TokenKind = exports.AppDomain = void 0;
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const joi_1 = __importDefault(require("joi"));
const locale_1 = require("./locale");
var AppDomain;
(function (AppDomain) {
    AppDomain["MERCHANT"] = "MERCHANT";
    AppDomain["CONSUMER"] = "CONSUMER";
    AppDomain["ADMIN"] = "ADMIN";
    AppDomain["DEVICE"] = "DEVICE";
})(AppDomain = exports.AppDomain || (exports.AppDomain = {}));
var TokenKind;
(function (TokenKind) {
    TokenKind["TOKEN"] = "TOKEN";
    TokenKind["EXTENDED_TOKEN"] = "EXTENDED_TOKEN";
    TokenKind["REFRESH_TOKEN"] = "REFRESH_TOKEN";
    TokenKind["REFRESH_EXTENDED_TOKEN"] = "REFRESH_EXTENDED_TOKEN";
})(TokenKind = exports.TokenKind || (exports.TokenKind = {}));
exports._id = joi_1.default.number().strict();
exports._idString = joi_1.default.number();
exports._string = joi_1.default.string().trim();
exports._boolean = joi_1.default.boolean();
exports._object = joi_1.default.object();
exports._modelInclude = joi_1.default.alternatives().try(exports._boolean, exports._object);
exports._userLogin = joi_1.default.string().max(250);
exports._tokenKind = joi_1.default.string()
    .trim()
    .valid(...Object.values(TokenKind));
exports._localeCode = joi_1.default.string()
    .trim()
    .valid(...Object.values(locale_1.LocaleCode));
exports._appDomain = joi_1.default.string()
    .trim()
    .valid(...Object.values(AppDomain));
// ===========
// ** Rules **
// ===========
exports._ruleAction = joi_1.default.string().trim();
exports._ruleSubject = joi_1.default.string().trim();
exports._ruleFields = joi_1.default.string().trim();
exports._ruleConditions = joi_1.default.object();
exports._ruleInverted = joi_1.default.boolean();
exports._rule = joi_1.default.object().keys({
    action: exports._ruleAction.required(),
    subject: exports._ruleSubject.required(),
    fields: exports._ruleFields,
    conditions: exports._ruleConditions,
    inverted: exports._ruleInverted
});
exports._rules = joi_1.default.array().items(exports._rule);
// ===================
// ** RolesMetadata **
// ===================
exports._roleModelSelect = joi_1.default.object().keys({ model: joi_1.default.string(), oneToOne: joi_1.default.boolean().default(false) });
exports._roleModelWhereUnique = joi_1.default.object().pattern(joi_1.default.string(), joi_1.default.any());
exports._roleModelWhere = joi_1.default.array().items(joi_1.default.object().pattern(joi_1.default.string(), joi_1.default.any()));
exports._roleModelFindUnique = joi_1.default.object().keys({ where: exports._roleModelWhereUnique });
exports._roleModelFindMany = joi_1.default.object().keys({ where: exports._roleModelWhere });
exports._roleModelUpdate = joi_1.default.object().keys({ where: exports._roleModelWhereUnique });
exports._roleModelUpdateMany = joi_1.default.object().keys({ where: exports._roleModelWhere });
exports._roleModelDelete = joi_1.default.object().keys({ where: exports._roleModelWhereUnique });
exports._roleModelDeleteMany = joi_1.default.object().keys({ where: exports._roleModelWhere });
exports._roleModelCreate = joi_1.default.object().keys({ data: joi_1.default.object().pattern(joi_1.default.string(), joi_1.default.any()) });
exports._roleModelCreateMany = joi_1.default.object().keys({ data: joi_1.default.object().pattern(joi_1.default.string(), joi_1.default.any()) });
exports._roleModel = joi_1.default.object().keys({
    '*': joi_1.default.object(),
    select: joi_1.default.object().pattern(joi_1.default.string(), [joi_1.default.boolean(), exports._roleModelSelect]),
    findUnique: exports._roleModelFindUnique,
    findMany: exports._roleModelFindMany,
    update: exports._roleModelUpdate,
    updateMany: exports._roleModelUpdateMany,
    delete: exports._roleModelDelete,
    deleteMany: exports._roleModelDeleteMany,
    create: exports._roleModelCreate,
    createMany: exports._roleModelCreateMany
});
exports._roleAttributes = {
    roleOrgId: exports._id,
    roleOrgCode: exports._string,
    roleOrgType: exports._string,
    roleType: exports._string
};
exports._roleMetadata = joi_1.default.object().keys({
    models: joi_1.default.object().pattern(joi_1.default.string(), exports._roleModel),
    attributes: joi_1.default.object().keys(exports._roleAttributes).pattern(joi_1.default.string(), joi_1.default.any())
});
exports._rolesMetadata = joi_1.default.array().items(exports._roleMetadata);
function validateOrThrowError(schema, data, options, fnName, errorCode) {
    const { error, value } = schema.validate(data, options);
    if (error) {
        (0, cm_libs_context_aware_error_1.throwError)(errorCode || cm_libs_context_aware_error_1.errors.INVALID_FORMAT, error.message, {
            function: fnName,
            details: error.details,
            text: { input: error.details?.[0]?.context?.peers || error.details?.[0]?.context?.key }
        });
    }
    return value;
}
exports.validateOrThrowError = validateOrThrowError;
//# sourceMappingURL=type.js.map